/****************************************************************************
** Meta object code from reading C++ file 'ktreeviewsearchline.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-sdk-6.7.0/engineexplorer/ktreeviewsearchline.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ktreeviewsearchline.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19KTreeViewSearchLineE_t {};
} // unnamed namespace

template <> constexpr inline auto KTreeViewSearchLine::qt_create_metaobjectdata<qt_meta_tag_ZN19KTreeViewSearchLineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTreeViewSearchLine",
        "addTreeView",
        "",
        "QTreeView*",
        "treeView",
        "removeTreeView",
        "updateSearch",
        "pattern",
        "setCaseSensitivity",
        "Qt::CaseSensitivity",
        "caseSensitivity",
        "setKeepParentsVisible",
        "value",
        "setSearchColumns",
        "QList<int>",
        "columns",
        "setTreeView",
        "setTreeViews",
        "QList<QTreeView*>",
        "treeViews",
        "itemMatches",
        "QModelIndex",
        "item",
        "row",
        "canChooseColumnsCheck",
        "queueSearch",
        "search",
        "activateSearch",
        "treeViewDeleted",
        "slotColumnActivated",
        "QAction*",
        "slotAllVisibleColumns",
        "rowsInserted",
        "parent",
        "start",
        "end",
        "caseSensitity",
        "keepParentsVisible"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'addTreeView'
        QtMocHelpers::SlotData<void(QTreeView *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'removeTreeView'
        QtMocHelpers::SlotData<void(QTreeView *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'updateSearch'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'updateSearch'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setCaseSensitivity'
        QtMocHelpers::SlotData<void(Qt::CaseSensitivity)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'setKeepParentsVisible'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'setSearchColumns'
        QtMocHelpers::SlotData<void(const QList<int> &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setTreeView'
        QtMocHelpers::SlotData<void(QTreeView *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'setTreeViews'
        QtMocHelpers::SlotData<void(const QList<QTreeView*> &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'itemMatches'
        QtMocHelpers::SlotData<bool(const QModelIndex &, int, const QString &) const>(20, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 21, 22 }, { QMetaType::Int, 23 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'canChooseColumnsCheck'
        QtMocHelpers::SlotData<bool()>(24, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'queueSearch'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'activateSearch'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'treeViewDeleted'
        QtMocHelpers::SlotData<void(QObject *)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 2 },
        }}),
        // Slot 'slotColumnActivated'
        QtMocHelpers::SlotData<void(QAction *)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 2 },
        }}),
        // Slot 'slotAllVisibleColumns'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'rowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int) const>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 33 }, { QMetaType::Int, 34 }, { QMetaType::Int, 35 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'caseSensitity'
        QtMocHelpers::PropertyData<Qt::CaseSensitivity>(36, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'keepParentsVisible'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KTreeViewSearchLine, qt_meta_tag_ZN19KTreeViewSearchLineE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTreeViewSearchLine::staticMetaObject = { {
    QMetaObject::SuperData::link<KLineEdit::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KTreeViewSearchLineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KTreeViewSearchLineE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19KTreeViewSearchLineE_t>.metaTypes,
    nullptr
} };

void KTreeViewSearchLine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KTreeViewSearchLine *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addTreeView((*reinterpret_cast<std::add_pointer_t<QTreeView*>>(_a[1]))); break;
        case 1: _t->removeTreeView((*reinterpret_cast<std::add_pointer_t<QTreeView*>>(_a[1]))); break;
        case 2: _t->updateSearch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->updateSearch(); break;
        case 4: _t->setCaseSensitivity((*reinterpret_cast<std::add_pointer_t<Qt::CaseSensitivity>>(_a[1]))); break;
        case 5: _t->setKeepParentsVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->setSearchColumns((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        case 7: _t->setTreeView((*reinterpret_cast<std::add_pointer_t<QTreeView*>>(_a[1]))); break;
        case 8: _t->setTreeViews((*reinterpret_cast<std::add_pointer_t<QList<QTreeView*>>>(_a[1]))); break;
        case 9: { bool _r = _t->itemMatches((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->canChooseColumnsCheck();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->queueSearch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->activateSearch(); break;
        case 13: _t->d->treeViewDeleted((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 14: _t->d->slotColumnActivated((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 15: _t->d->slotAllVisibleColumns(); break;
        case 16: _t->rowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Qt::CaseSensitivity*>(_v) = _t->caseSensitivity(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->keepParentsVisible(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCaseSensitivity(*reinterpret_cast<Qt::CaseSensitivity*>(_v)); break;
        case 1: _t->setKeepParentsVisible(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KTreeViewSearchLine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTreeViewSearchLine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KTreeViewSearchLineE_t>.strings))
        return static_cast<void*>(this);
    return KLineEdit::qt_metacast(_clname);
}

int KTreeViewSearchLine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KLineEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN25KTreeViewSearchLineWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto KTreeViewSearchLineWidget::qt_create_metaobjectdata<qt_meta_tag_ZN25KTreeViewSearchLineWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTreeViewSearchLineWidget",
        "createWidgets",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'createWidgets'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KTreeViewSearchLineWidget, qt_meta_tag_ZN25KTreeViewSearchLineWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTreeViewSearchLineWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KTreeViewSearchLineWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KTreeViewSearchLineWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25KTreeViewSearchLineWidgetE_t>.metaTypes,
    nullptr
} };

void KTreeViewSearchLineWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KTreeViewSearchLineWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->createWidgets(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *KTreeViewSearchLineWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTreeViewSearchLineWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KTreeViewSearchLineWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KTreeViewSearchLineWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
