/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<coloreditor.h>)
#  include <coloreditor.h>
#endif
#if __has_include(<themelistmodel.h>)
#  include <themelistmodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_themeexplorer()
{
    qmlRegisterModule("org.kde.plasma.themeexplorer", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<ColorEditor>("org.kde.plasma.themeexplorer", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<ThemeListModel>("org.kde.plasma.themeexplorer", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.themeexplorer", 254, 254);
}

static const QQmlModuleRegistration orgkdeplasmathemeexplorerRegistration("org.kde.plasma.themeexplorer", qml_register_types_org_kde_plasma_themeexplorer);
