/********************************************************************************
** Form generated from reading UI file 'engineexplorer.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ENGINEEXPLORER_H
#define UI_ENGINEEXPLORER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktitlewidget.h"
#include "ktreeviewsearchline.h"
#include "titlecombobox.h"

QT_BEGIN_NAMESPACE

class Ui_EngineExplorer
{
public:
    QVBoxLayout *verticalLayout;
    KTitleWidget *m_title;
    TitleComboBox *m_engines;
    QHBoxLayout *hboxLayout;
    QLineEdit *m_sourceRequester;
    QSpinBox *m_updateInterval;
    QPushButton *m_sourceRequesterButton;
    QHBoxLayout *horizontalLayout;
    QLineEdit *m_serviceRequester;
    QPushButton *m_serviceRequesterButton;
    KTreeViewSearchLine *m_searchLine;
    QTreeView *m_data;

    void setupUi(QWidget *EngineExplorer)
    {
        if (EngineExplorer->objectName().isEmpty())
            EngineExplorer->setObjectName("EngineExplorer");
        EngineExplorer->resize(528, 286);
        verticalLayout = new QVBoxLayout(EngineExplorer);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        m_title = new KTitleWidget(EngineExplorer);
        m_title->setObjectName("m_title");

        verticalLayout->addWidget(m_title);

        m_engines = new TitleComboBox(EngineExplorer);
        m_engines->setObjectName("m_engines");

        verticalLayout->addWidget(m_engines);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        m_sourceRequester = new QLineEdit(EngineExplorer);
        m_sourceRequester->setObjectName("m_sourceRequester");
        m_sourceRequester->setEnabled(false);
        m_sourceRequester->setMinimumSize(QSize(100, 0));
        m_sourceRequester->setProperty("showClearButton", QVariant(true));

        hboxLayout->addWidget(m_sourceRequester);

        m_updateInterval = new QSpinBox(EngineExplorer);
        m_updateInterval->setObjectName("m_updateInterval");
        m_updateInterval->setEnabled(false);
        m_updateInterval->setAutoFillBackground(false);
        m_updateInterval->setWrapping(false);
        m_updateInterval->setFrame(true);
        m_updateInterval->setReadOnly(false);
        m_updateInterval->setAccelerated(false);
        m_updateInterval->setMaximum(10000000);
        m_updateInterval->setSingleStep(50);

        hboxLayout->addWidget(m_updateInterval);

        m_sourceRequesterButton = new QPushButton(EngineExplorer);
        m_sourceRequesterButton->setObjectName("m_sourceRequesterButton");
        m_sourceRequesterButton->setEnabled(false);

        hboxLayout->addWidget(m_sourceRequesterButton);


        verticalLayout->addLayout(hboxLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_serviceRequester = new QLineEdit(EngineExplorer);
        m_serviceRequester->setObjectName("m_serviceRequester");
        m_serviceRequester->setEnabled(false);
        m_serviceRequester->setMinimumSize(QSize(120, 0));
        m_serviceRequester->setProperty("showClearButton", QVariant(true));

        horizontalLayout->addWidget(m_serviceRequester);

        m_serviceRequesterButton = new QPushButton(EngineExplorer);
        m_serviceRequesterButton->setObjectName("m_serviceRequesterButton");
        m_serviceRequesterButton->setEnabled(false);

        horizontalLayout->addWidget(m_serviceRequesterButton);


        verticalLayout->addLayout(horizontalLayout);

        m_searchLine = new KTreeViewSearchLine(EngineExplorer);
        m_searchLine->setObjectName("m_searchLine");

        verticalLayout->addWidget(m_searchLine);

        m_data = new QTreeView(EngineExplorer);
        m_data->setObjectName("m_data");
        m_data->setEditTriggers(QAbstractItemView::NoEditTriggers);
        m_data->setAllColumnsShowFocus(true);

        verticalLayout->addWidget(m_data);

        QWidget::setTabOrder(m_engines, m_sourceRequester);
        QWidget::setTabOrder(m_sourceRequester, m_sourceRequesterButton);
        QWidget::setTabOrder(m_sourceRequesterButton, m_serviceRequester);
        QWidget::setTabOrder(m_serviceRequester, m_serviceRequesterButton);
        QWidget::setTabOrder(m_serviceRequesterButton, m_data);

        retranslateUi(EngineExplorer);

        QMetaObject::connectSlotsByName(EngineExplorer);
    } // setupUi

    void retranslateUi(QWidget *EngineExplorer)
    {
        m_title->setText(tr2i18n("Plasma DataEngine Explorer", nullptr));
        m_sourceRequester->setPlaceholderText(tr2i18n("Source name", nullptr));
        m_updateInterval->setSpecialValueText(tr2i18n("Update on demand", nullptr));
        m_updateInterval->setSuffix(tr2i18n(" ms", nullptr));
        m_updateInterval->setPrefix(tr2i18n("Update Every ", nullptr));
        m_sourceRequesterButton->setText(tr2i18n("Request Source", nullptr));
        m_serviceRequester->setPlaceholderText(tr2i18n("Service for source", nullptr));
        m_serviceRequesterButton->setText(tr2i18n("Request Service for Source", nullptr));
        (void)EngineExplorer;
    } // retranslateUi

};

namespace Ui {
    class EngineExplorer: public Ui_EngineExplorer {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ENGINEEXPLORER_H

