/****************************************************************************
** Meta object code from reading C++ file 'coloreditor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-sdk-6.7.0/themeexplorer/src/coloreditor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'coloreditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ColorEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto ColorEditor::qt_create_metaobjectdata<qt_meta_tag_ZN11ColorEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ColorEditor",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "colorsChanged",
        "themeChanged",
        "save",
        "textColor",
        "QColor",
        "highlightColor",
        "backgroundColor",
        "linkColor",
        "visitedLinkColor",
        "buttonTextColor",
        "buttonBackgroundColor",
        "buttonHoverColor",
        "buttonFocusColor",
        "viewTextColor",
        "viewBackgroundColor",
        "viewHoverColor",
        "viewFocusColor",
        "complementaryTextColor",
        "complementaryBackgroundColor",
        "complementaryHoverColor",
        "complementaryFocusColor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'colorsChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'themeChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'save'
        QtMocHelpers::MethodData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'textColor'
        QtMocHelpers::PropertyData<QColor>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'highlightColor'
        QtMocHelpers::PropertyData<QColor>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'backgroundColor'
        QtMocHelpers::PropertyData<QColor>(13, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'linkColor'
        QtMocHelpers::PropertyData<QColor>(14, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'visitedLinkColor'
        QtMocHelpers::PropertyData<QColor>(15, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'buttonTextColor'
        QtMocHelpers::PropertyData<QColor>(16, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'buttonBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(17, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'buttonHoverColor'
        QtMocHelpers::PropertyData<QColor>(18, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'buttonFocusColor'
        QtMocHelpers::PropertyData<QColor>(19, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'viewTextColor'
        QtMocHelpers::PropertyData<QColor>(20, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'viewBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(21, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'viewHoverColor'
        QtMocHelpers::PropertyData<QColor>(22, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'viewFocusColor'
        QtMocHelpers::PropertyData<QColor>(23, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'complementaryTextColor'
        QtMocHelpers::PropertyData<QColor>(24, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'complementaryBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(25, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'complementaryHoverColor'
        QtMocHelpers::PropertyData<QColor>(26, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'complementaryFocusColor'
        QtMocHelpers::PropertyData<QColor>(27, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<ColorEditor, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ColorEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ColorEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ColorEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ColorEditorE_t>.metaTypes,
    nullptr
} };

void ColorEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ColorEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->colorsChanged(); break;
        case 1: _t->themeChanged(); break;
        case 2: _t->save(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ColorEditor::*)()>(_a, &ColorEditor::colorsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColorEditor::*)()>(_a, &ColorEditor::themeChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QColor*>(_v) = _t->textColor(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->highlightColor(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->backgroundColor(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->linkColor(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->visitedLinkColor(); break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->buttonTextColor(); break;
        case 6: *reinterpret_cast<QColor*>(_v) = _t->buttonBackgroundColor(); break;
        case 7: *reinterpret_cast<QColor*>(_v) = _t->buttonHoverColor(); break;
        case 8: *reinterpret_cast<QColor*>(_v) = _t->buttonFocusColor(); break;
        case 9: *reinterpret_cast<QColor*>(_v) = _t->viewTextColor(); break;
        case 10: *reinterpret_cast<QColor*>(_v) = _t->viewBackgroundColor(); break;
        case 11: *reinterpret_cast<QColor*>(_v) = _t->viewHoverColor(); break;
        case 12: *reinterpret_cast<QColor*>(_v) = _t->viewFocusColor(); break;
        case 13: *reinterpret_cast<QColor*>(_v) = _t->complementaryTextColor(); break;
        case 14: *reinterpret_cast<QColor*>(_v) = _t->complementaryBackgroundColor(); break;
        case 15: *reinterpret_cast<QColor*>(_v) = _t->complementaryHoverColor(); break;
        case 16: *reinterpret_cast<QColor*>(_v) = _t->complementaryFocusColor(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 1: _t->setHighlightColor(*reinterpret_cast<QColor*>(_v)); break;
        case 2: _t->setBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 3: _t->setLinkColor(*reinterpret_cast<QColor*>(_v)); break;
        case 4: _t->setVisitedLinkColor(*reinterpret_cast<QColor*>(_v)); break;
        case 5: _t->setButtonTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 6: _t->setButtonBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 7: _t->setButtonHoverColor(*reinterpret_cast<QColor*>(_v)); break;
        case 8: _t->setButtonFocusColor(*reinterpret_cast<QColor*>(_v)); break;
        case 9: _t->setViewTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 10: _t->setViewBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 11: _t->setViewHoverColor(*reinterpret_cast<QColor*>(_v)); break;
        case 12: _t->setViewFocusColor(*reinterpret_cast<QColor*>(_v)); break;
        case 13: _t->setComplementaryTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 14: _t->setComplementaryBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 15: _t->setComplementaryHoverColor(*reinterpret_cast<QColor*>(_v)); break;
        case 16: _t->setComplementaryFocusColor(*reinterpret_cast<QColor*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ColorEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColorEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ColorEditorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ColorEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void ColorEditor::colorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ColorEditor::themeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
