/********************************************************************************
** Form generated from reading UI file 'serviceviewer.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SERVICEVIEWER_H
#define UI_SERVICEVIEWER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ServiceViewer
{
public:
    QGridLayout *gridLayout;
    KComboBox *m_operations;
    QLabel *m_operationsLabel;
    QSpacerItem *horizontalSpacer;
    QFrame *line;
    QTableWidget *m_operationDescription;
    QLabel *m_operationStatus;
    QLabel *m_title;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *ServiceViewer)
    {
        if (ServiceViewer->objectName().isEmpty())
            ServiceViewer->setObjectName("ServiceViewer");
        ServiceViewer->resize(405, 275);
        gridLayout = new QGridLayout(ServiceViewer);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        m_operations = new KComboBox(ServiceViewer);
        m_operations->setObjectName("m_operations");
        m_operations->setEnabled(false);

        gridLayout->addWidget(m_operations, 4, 3, 2, 1);

        m_operationsLabel = new QLabel(ServiceViewer);
        m_operationsLabel->setObjectName("m_operationsLabel");
        m_operationsLabel->setEnabled(false);

        gridLayout->addWidget(m_operationsLabel, 4, 2, 2, 1);

        horizontalSpacer = new QSpacerItem(217, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 5, 4, 1, 1);

        line = new QFrame(ServiceViewer);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 1, 1, 4, 4);

        m_operationDescription = new QTableWidget(ServiceViewer);
        if (m_operationDescription->columnCount() < 2)
            m_operationDescription->setColumnCount(2);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        m_operationDescription->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        m_operationDescription->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        m_operationDescription->setObjectName("m_operationDescription");
        m_operationDescription->setEnabled(false);

        gridLayout->addWidget(m_operationDescription, 6, 0, 1, 5);

        m_operationStatus = new QLabel(ServiceViewer);
        m_operationStatus->setObjectName("m_operationStatus");

        gridLayout->addWidget(m_operationStatus, 7, 0, 1, 5);

        m_title = new QLabel(ServiceViewer);
        m_title->setObjectName("m_title");
        m_title->setText(QString::fromUtf8("Engine; Source; Service"));

        gridLayout->addWidget(m_title, 0, 0, 2, 5);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 2, 0, 1, 1);

#if QT_CONFIG(shortcut)
        m_operationsLabel->setBuddy(m_operations);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ServiceViewer);

        QMetaObject::connectSlotsByName(ServiceViewer);
    } // setupUi

    void retranslateUi(QWidget *ServiceViewer)
    {
        m_operationsLabel->setText(tr2i18n("Opera&tion:", nullptr));
        QTableWidgetItem *___qtablewidgetitem = m_operationDescription->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Key", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = m_operationDescription->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Value", nullptr));
        m_operationStatus->setText(tr2i18n("Operation count", nullptr));
        (void)ServiceViewer;
    } // retranslateUi

};

namespace Ui {
    class ServiceViewer: public Ui_ServiceViewer {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SERVICEVIEWER_H

