/****************************************************************************
** Meta object code from reading C++ file 'lnflogic.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-sdk-6.7.0/lookandfeelexplorer/lnflogic.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lnflogic.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8LnfLogicE_t {};
} // unnamed namespace

template <> constexpr inline auto LnfLogic::qt_create_metaobjectdata<qt_meta_tag_ZN8LnfLogicE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LnfLogic",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "themeChanged",
        "",
        "messageRequested",
        "ErrorLevel",
        "level",
        "message",
        "needsSaveChanged",
        "nameChanged",
        "commentChanged",
        "authorChanged",
        "emailChanged",
        "websiteChanged",
        "licenseChanged",
        "performLayoutDumpChanged",
        "performDefaultsDumpChanged",
        "thumbnailPathChanged",
        "save",
        "createNewTheme",
        "pluginName",
        "name",
        "comment",
        "author",
        "email",
        "license",
        "website",
        "processThumbnail",
        "path",
        "openFile",
        "lnfList",
        "LnfListModel*",
        "theme",
        "isWritable",
        "themeFolder",
        "thumbnailPath",
        "performLayoutDump",
        "performDefaultsDump",
        "needsSave",
        "Info",
        "Error"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'themeChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'messageRequested'
        QtMocHelpers::SignalData<void(enum ErrorLevel, const QString &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'needsSaveChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'commentChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authorChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emailChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'websiteChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'licenseChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'performLayoutDumpChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'performDefaultsDumpChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'thumbnailPathChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'save'
        QtMocHelpers::MethodData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'createNewTheme'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, const QString &)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 }, { QMetaType::QString, 24 }, { QMetaType::QString, 25 }, { QMetaType::QString, 26 },
            { QMetaType::QString, 27 }, { QMetaType::QString, 28 }, { QMetaType::QString, 29 },
        }}),
        // Method 'processThumbnail'
        QtMocHelpers::MethodData<void(const QString &)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Method 'openFile'
        QtMocHelpers::MethodData<QString()>(32, 6, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'lnfList'
        QtMocHelpers::PropertyData<LnfListModel*>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'theme'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isWritable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'themeFolder'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'comment'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'author'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'email'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'website'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'license'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'thumbnailPath'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'performLayoutDump'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'performDefaultsDump'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'needsSave'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ErrorLevel'
        QtMocHelpers::EnumData<enum ErrorLevel>(8, 8, QMC::EnumFlags{}).add({
            {   42, ErrorLevel::Info },
            {   43, ErrorLevel::Error },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<LnfLogic, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject LnfLogic::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8LnfLogicE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8LnfLogicE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8LnfLogicE_t>.metaTypes,
    nullptr
} };

void LnfLogic::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LnfLogic *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->themeChanged(); break;
        case 1: _t->messageRequested((*reinterpret_cast<std::add_pointer_t<enum ErrorLevel>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->needsSaveChanged(); break;
        case 3: _t->nameChanged(); break;
        case 4: _t->commentChanged(); break;
        case 5: _t->authorChanged(); break;
        case 6: _t->emailChanged(); break;
        case 7: _t->websiteChanged(); break;
        case 8: _t->licenseChanged(); break;
        case 9: _t->performLayoutDumpChanged(); break;
        case 10: _t->performDefaultsDumpChanged(); break;
        case 11: _t->thumbnailPathChanged(); break;
        case 12: _t->save(); break;
        case 13: _t->createNewTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7]))); break;
        case 14: _t->processThumbnail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: { QString _r = _t->openFile();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LnfLogic::*)()>(_a, &LnfLogic::themeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LnfLogic::*)(ErrorLevel , const QString & )>(_a, &LnfLogic::messageRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LnfLogic::*)()>(_a, &LnfLogic::needsSaveChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LnfLogic::*)()>(_a, &LnfLogic::nameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LnfLogic::*)()>(_a, &LnfLogic::commentChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LnfLogic::*)()>(_a, &LnfLogic::authorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (LnfLogic::*)()>(_a, &LnfLogic::emailChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (LnfLogic::*)()>(_a, &LnfLogic::websiteChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (LnfLogic::*)()>(_a, &LnfLogic::licenseChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (LnfLogic::*)()>(_a, &LnfLogic::performLayoutDumpChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (LnfLogic::*)()>(_a, &LnfLogic::performDefaultsDumpChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (LnfLogic::*)()>(_a, &LnfLogic::thumbnailPathChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<LnfListModel**>(_v) = _t->lnfList(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->theme(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isWritable(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->themeFolder(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->comment(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->author(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->email(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->website(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->license(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->thumbnailPath(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->performLayoutDump(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->performDefaultsDump(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->needsSave(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setTheme(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setComment(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setAuthor(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setEmail(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setWebsite(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setLicense(*reinterpret_cast<QString*>(_v)); break;
        case 11: _t->setPerformLayoutDump(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setPerformDefaultsDump(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LnfLogic::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LnfLogic::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8LnfLogicE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int LnfLogic::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void LnfLogic::themeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LnfLogic::messageRequested(ErrorLevel _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void LnfLogic::needsSaveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LnfLogic::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LnfLogic::commentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void LnfLogic::authorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void LnfLogic::emailChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void LnfLogic::websiteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void LnfLogic::licenseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void LnfLogic::performLayoutDumpChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void LnfLogic::performDefaultsDumpChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void LnfLogic::thumbnailPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
